summaryrefslogtreecommitdiffstats
path: root/tools/builder_common.sh
diff options
context:
space:
mode:
Diffstat (limited to 'tools/builder_common.sh')
-rw-r--r--tools/builder_common.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/tools/builder_common.sh b/tools/builder_common.sh
index d238d1d..fbdd872 100644
--- a/tools/builder_common.sh
+++ b/tools/builder_common.sh
@@ -329,8 +329,8 @@ create_ova_image() {
if [ -z "${OVA_SWAP_PART_SIZE_IN_GB}" -o "${OVA_SWAP_PART_SIZE_IN_GB}" = "0" ]; then
# first partition size (freebsd-ufs)
local OVA_FIRST_PART_SIZE_IN_GB=${VMDK_DISK_CAPACITY_IN_GB}
- # Calculate real first partition size, removing 128 blocks (65536 bytes) beginning/loader
- local OVA_FIRST_PART_SIZE=$((${OVA_FIRST_PART_SIZE_IN_GB}*1024*1024*1024-65536))
+ # Calculate real first partition size, removing 256 blocks (131072 bytes) beginning/loader
+ local OVA_FIRST_PART_SIZE=$((${OVA_FIRST_PART_SIZE_IN_GB}*1024*1024*1024-131072))
# Unset swap partition size variable
unset OVA_SWAP_PART_SIZE
# Parameter used by mkimg
@@ -340,8 +340,8 @@ create_ova_image() {
local OVA_FIRST_PART_SIZE_IN_GB=$((VMDK_DISK_CAPACITY_IN_GB-OVA_SWAP_PART_SIZE_IN_GB))
# Use first partition size in g
local OVA_FIRST_PART_SIZE="${OVA_FIRST_PART_SIZE_IN_GB}g"
- # Calculate real swap size, removing 128 blocks (65536 bytes) beginning/loader
- local OVA_SWAP_PART_SIZE=$((${OVA_SWAP_PART_SIZE_IN_GB}*1024*1024*1024-65536))
+ # Calculate real swap size, removing 256 blocks (131072 bytes) beginning/loader
+ local OVA_SWAP_PART_SIZE=$((${OVA_SWAP_PART_SIZE_IN_GB}*1024*1024*1024-131072))
# Parameter used by mkimg
local OVA_SWAP_PART_PARAM="-p freebsd-swap/swap0::${OVA_SWAP_PART_SIZE}"
fi
OpenPOWER on IntegriCloud